==> piwigo-2.5.1.zip: piwigo/language/sl_SI/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Kot previdnostni ukrep so sledeči vtičniki onemogočeni. Preveriti morate posodobitve za te vtičnike in jih nato ponovno omogočiti:';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Od predhodnje nastavitve so shranjene le predpone sličic in e-poštni naslov skrbnika spletne strani';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'V primeru težav naredite vzdrževalno preverjanje preko [Administracija>Orodja>Vzdrževanje]';
$lang['SQL queries'] = 'SQL poizvedbe';
$lang['Statistics'] = 'Statistika';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Ta stran predlaga, da nadgradite podatkovno bazo vaše Piwigo različice na novejšo različico. Čarovnik nadgradnje je zaznal, da trenutno uporabljate <strong>različico %s</strong> (ali enakovredno).';
$lang['Upgrade'] = 'Nadgradi';
$lang['Upgrade from version %s to %s'] = 'Nadgradi iz različice %s na %s';
$lang['Upgrade informations'] = 'Informacije nadgradnje';
$lang['User permissions and group permissions have been erased'] = 'Dovoljenja uporabnikov in skupin so bila izbrisana';
$lang['You do not have access rights to run upgrade'] = 'Nimate dovoljenja za izvedbo nadgradnje';
$lang['total SQL time'] = 'skupen SQL čas';
$lang['total upgrade time'] = 'skupen čas nadgradnje';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'V <i>%s</i>, pred <b>?></b>, vstavi:';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Nadgradnjo lahko opravi le Administrator.Prosimo prijavite se spodaj:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Kot previdnostni ukrep so sledeče preobleke onemogočene. Preveriti morate posodobitve za te preobleke in jih nato ponovno omogočiti:';
$lang['All sub-albums of private albums become private'] = 'Vsi pod-albumi zasebnega albuma postanejo zasebni';
?>

==> piwigo-16.2.0.zip: piwigo/language/sl_SI/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Kot previdnostni ukrep so sledeči vtičniki onemogočeni. Preveriti morate posodobitve za te vtičnike in jih nato ponovno omogočiti:';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Od predhodnje nastavitve so shranjene le predpone sličic in e-poštni naslov skrbnika spletne strani';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'V primeru težav naredite vzdrževalno preverjanje preko [Administracija>Orodja>Vzdrževanje]';
$lang['SQL queries'] = 'SQL poizvedbe';
$lang['Statistics'] = 'Statistika';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Ta stran predlaga, da nadgradite podatkovno bazo vaše Piwigo različice na novejšo različico. Čarovnik nadgradnje je zaznal, da trenutno uporabljate <strong>različico %s</strong> (ali enakovredno).';
$lang['Upgrade'] = 'Nadgradi';
$lang['Upgrade from version %s to %s'] = 'Nadgradi iz različice %s na različico %s';
$lang['Upgrade informations'] = 'Povzetek posodobitve';
$lang['User permissions and group permissions have been erased'] = 'Dovoljenja uporabnikov in skupin so bila izbrisana';
$lang['You do not have access rights to run upgrade'] = 'Nimate dovoljenja za izvedbo nadgradnje';
$lang['total SQL time'] = 'skupen SQL čas';
$lang['total upgrade time'] = 'skupen čas nadgradnje';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'V <i>%s</i>, pred <b>?></b>, vstavi:';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Nadgradnjo lahko opravi le Administrator. Prosimo prijavite se spodaj:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Kot previdnostni ukrep so sledeče preobleke onemogočene. Preveriti morate posodobitve za te preobleke in jih nato ponovno omogočiti:';
$lang['All sub-albums of private albums become private'] = 'Vsi pod-albumi zasebnega albuma postanejo zasebni';
$lang['Discover what\'s new in Piwigo %s'] = 'Odkrijte, kaj je novega v Piwigo %s';
